FtOutputCommand

Enum FtOutputCommand 

pub enum FtOutputCommand {
    On(u8),
    Off,
    High,
    Low,
}

Variants



On(u8)

Turn the output on with a specific PWM intensity (in percent).



Off

Turn the output off by opening the circuit.



High

Connect the output to the high voltage level (Vcc). This is equivalent to On(HIGH_INTENSITY).



Low

Connect the output to the low voltage level (GND).

Note: This is different from Off, where the circuit is open.